@@ -1,19 +1,10 @@
-/*************************************************************************
- *  Copyright (C) 2008, 2010 by Volker Lanz <vl@fidra.de>                *
- *                                                                       *
- *  This program is free software; you can redistribute it and/or        *
- *  modify it under the terms of the GNU General Public License as       *
- *  published by the Free Software Foundation; either version 3 of       *
- *  the License, or (at your option) any later version.                  *
- *                                                                       *
- *  This program is distributed in the hope that it will be useful,      *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of       *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
- *  GNU General Public License for more details.                         *
- *                                                                       *
- *  You should have received a copy of the GNU General Public License    *
- *  along with this program.  If not, see <http://www.gnu.org/licenses/>.*
- *************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2008-2010 Volker Lanz <vl@fidra.de>
+    SPDX-FileCopyrightText: 2016-2018 Andrius Štikonas <andrius@stikonas.eu>
+    SPDX-FileCopyrightText: 2018 Huzaifa Faruqui <huzaifafaruqui@gmail.com>
+
+    SPDX-License-Identifier: GPL-3.0-or-later
+*/
 
 #ifndef KPMCORE_JOB_H
 #define KPMCORE_JOB_H
@@ -58,7 +49,7 @@ protected:
     Job();
 
 public:
-    virtual ~Job() {}
+    ~Job() override {}
 
 Q_SIGNALS:
     void started();
@@ -80,7 +71,7 @@ public:
     }
 
     void emitProgress(int i);
-    void updateReport(const QVariantMap& reportString);
+    void updateReport(const QString& report);
 
 protected:
     bool copyBlocks(Report& report, CopyTarget& target, CopySource& source);
