@@ -1,20 +1,9 @@
-/*************************************************************************
- *  Copyright (C) 2008, 2010 by Volker Lanz <vl@fidra.de>                *
- *  Copyright (C) 2016 by Andrius Štikonas <andrius@stikonas.eu>         *
- *                                                                       *
- *  This program is free software; you can redistribute it and/or        *
- *  modify it under the terms of the GNU General Public License as       *
- *  published by the Free Software Foundation; either version 3 of       *
- *  the License, or (at your option) any later version.                  *
- *                                                                       *
- *  This program is distributed in the hope that it will be useful,      *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of       *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
- *  GNU General Public License for more details.                         *
- *                                                                       *
- *  You should have received a copy of the GNU General Public License    *
- *  along with this program.  If not, see <http://www.gnu.org/licenses/>.*
- *************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2008-2010 Volker Lanz <vl@fidra.de>
+    SPDX-FileCopyrightText: 2014-2020 Andrius Štikonas <andrius@stikonas.eu>
+
+    SPDX-License-Identifier: GPL-3.0-or-later
+*/
 
 #include "jobs/setpartflagsjob.h"
 
@@ -65,7 +54,7 @@ bool SetPartFlagsJob::run(Report& parent)
             int count = 0;
 
             for (const auto &f : PartitionTable::flagList()) {
-                emit progress(++count);
+                Q_EMIT progress(++count);
 
                 const bool oldState = (partition().activeFlags() & f) ? true : false;
                 const bool state = (flags() & f) ? true : false;
